@@ -14,8 +14,10 @@ from copy import deepcopy
 # Constants
 ROOT: str = stp.get_root_path(__file__, go_up=1)
 GITHUB_REPO: str = "https://github.com/mcbookshelf/bookshelf/releases"
+API_URL: str = "https://api.github.com/repos/mcbookshelf/bookshelf/releases/latest"
+DESTINATION_FOLDER: str = f"{ROOT}/src/python_datapack/dependencies"
+CONFIG_PATH: str = f"{DESTINATION_FOLDER}/bookshelf_config.json"
 DEPS_TO_UPDATE: str = "src/python_datapack/dependencies/bookshelf.py"
-DESTINATION_FOLDER: str = f"{ROOT}/src/python_datapack/dependencies/datapack"
 MODULE_TEMPLATE: dict = {"version": [0, 0, 0], "name": "Title Name", "url": GITHUB_REPO, "is_used": False}
 
 
@@ -49,9 +51,8 @@ def download_latest_release() -> None:
 		...
 	}
 	"""
-	api_url: str = "https://api.github.com/repos/mcbookshelf/bookshelf/releases/latest"
-	stp.info(f"Fetching latest release from {api_url}")
-	response: requests.Response = requests.get(api_url)
+	stp.info(f"Fetching latest release from {API_URL}")
+	response: requests.Response = requests.get(API_URL)
 	if response.status_code != 200:
 		stp.info(f"Error fetching release info: {response.status_code}")
 		return
@@ -62,7 +63,7 @@ def download_latest_release() -> None:
 
 	modules: dict = {}
 	assets: list[dict] = release_info.get("assets", [])
-	os.makedirs(DESTINATION_FOLDER, exist_ok=True)
+	os.makedirs(f"{DESTINATION_FOLDER}/datapack", exist_ok=True)
 
 	# Filter assets
 	assets = [asset for asset in assets if re.match(r"^bs\..*\.zip$", asset.get("name", ""))]
@@ -81,7 +82,7 @@ def download_latest_release() -> None:
 			stp.warning(f"Failed to download {file_name}: HTTP {asset_response.status_code}")
 			return
 
-		local_zip_path: str = f"{DESTINATION_FOLDER}/{module_name}.zip"
+		local_zip_path: str = f"{DESTINATION_FOLDER}/datapack/{module_name}.zip"
 		with open(local_zip_path, "wb") as f:
 			f.write(asset_response.content)
 		stp.debug(f"Downloaded '{file_name}' to '...{local_zip_path[-40:]}'")
@@ -110,6 +111,11 @@ BOOKSHELF_MODULES = {dumped}
 		f.write(file_content)
 	stp.info(f"Updated '{DEPS_TO_UPDATE}' with new module information.")
 
+	# Update the config file
+	with open(CONFIG_PATH, "w") as f:
+		stp.super_json_dump({"version": tag_name}, f)
+	stp.info(f"Updated '{CONFIG_PATH}' with new version information.")
+
 # Main
 if __name__ == "__main__":
 	download_latest_release()
