@@ -1,15 +1,15 @@
 
 # Imports
-from ..utils.print import *
-from ..utils.io import *
+import os
+import stouputils as stp
 
 # Utils functions for fonts (item start at 0x0000, pages at 0xa000)
-# Return the character that will be used for font, ex: "\u0002" with i = 2
-def get_font(i: int):
+# Return the character that will be used for font, ex: chr(0x0002) with i = 2
+def get_font(i: int) -> str:
 	i += 0x0020	# Minecraft only allow starting this value
 	if i > 0xffff:
-		error(f"Font index {i} is too big. Maximum is 0xffff.")
-	return f"\\u{i:04x}"
+		stp.error(f"Font index {i} is too big. Maximum is 0xffff.")
+	return chr(i)
 def get_page_font(i: int) -> str:
 	return get_font(i + 0x1000)
 def get_next_font() -> str:	# Returns an incrementing value for each craft
@@ -21,7 +21,7 @@ def get_next_font() -> str:	# Returns an incrementing value for each craft
 # Constants
 COMPONENTS_TO_INCLUDE: list[str] = ["item_name", "lore", "custom_name", "damage", "max_damage"]
 SQUARE_SIZE: int = 32
-MANUAL_ASSETS_PATH: str = clean_path(os.path.dirname(os.path.realpath(__file__)) + "/")
+MANUAL_ASSETS_PATH: str = stp.clean_path(os.path.dirname(os.path.realpath(__file__)) + "/")
 TEMPLATES_PATH: str = MANUAL_ASSETS_PATH + "templates"
 FONT_FILE: str = "manual"
 BORDER_COLOR_HEX: int = 0xB64E2F
